<!doctype html>
<title>{% block title %}{% endblock %} - {{ SITE_NAME }}</title>
<meta http-equiv="content-type" content="text/html; charset=utf-8">
<link rel=stylesheet href={{ url_for('static', filename='pygments.css') }}>
<link rel=stylesheet href={{ url_for('static', filename='klaus.css') }}>
<link rel=icon type="image/png" href="{{ url_for('static', filename='favicon.png') }}" />

<script src={{ url_for('static', filename='klaus.js') }}></script>

<header>
  <a href={{ url_for('repo_list') }}>
    {{ SITE_NAME }}
  </a>
  <span class=breadcrumbs>{% block breadcrumbs %}{% endblock %}</span>
  {% block extra_header %}{% endblock %}
</header>

<div id=content>
{% block content %}{% endblock %}
</div>

<footer>
  powered by <a href="https://github.com/jonashaag/klaus">klaus</a> {{ KLAUS_VERSION }},
  a simple Git viewer by Jonas Haag
</footer>
