<div class=tree>
  <h2>Tree @<a href="{{ url_for('commit', repo=repo.name, rev=rev) }}">{{ rev|shorten_sha1 }}</a>
    <span>(<a href="{{ url_for('download', repo=repo.name, rev=rev) }}">Download .tar.gz</a>)</span>
  </h2>
  <ul>
    {% for _, name, fullpath in root_tree.dirs %}
    <li><a href="{{ url_for('history', repo=repo.name, rev=rev, path=fullpath) }}" class=dir>{{ name|force_unicode }}</a></li>
    {% endfor %}
    {% for _, name, fullpath in root_tree.files %}
    <li><a href="{{ url_for('blob', repo=repo.name, rev=rev, path=fullpath) }}">{{ name|force_unicode }}</a></li>
    {% endfor %}
  </ul>
</div>
