{% extends 'skeleton.html' %}

{% block title %}Repository list{% endblock %}

{% block content %}

<h2>
  Repositories
  <span>
    (<a href="?by-last-update=yep">order by last update</a>)
  </span>
</h2>
<ul class=repolist>
  {% for repo in repos %}
    {% set last_updated_at = repo.get_last_updated_at() %}
    {% set description = repo.get_description() %}
    <li>
      <a
        {% if last_updated_at %}
          href="{{ url_for('history', repo=repo.name) }}"
        {% endif %}
      >
        <div class=name>{{ repo.name }}</div>
        {% if description %}
          <div class=description>{{ description }}</div>
        {% endif %}
        <div class=last-updated>
        {% if last_updated_at is not none %}
          last updated {{ last_updated_at|timesince }}
        {% else %}
          no commits yet
        {% endif %}
        </div>
      </a>
    </li>
  {% endfor %}
</ul>

{% endblock %}
